"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExternalLinkNodeParser = void 0;
const creator_1 = require("./creator");
const hrefFirstUrlRegExp = /\[https?:\/\/[^\s\]]+(?:\s+[^\]]*[^\s])?\]/;
const contentFirstUrlRegExp = /\[[^\]]*[^\s]\s+https?:\/\/[^\s\]]+\]/;
const httpRegExp = /(?<=^| )https?:\/\/[^\s\]]+/;
const createExternalLinkNode = target => {
    if (target.startsWith('[') && target.endsWith(']')) {
        target = target.substring(1, target.length - 1);
    }
    const isHrefFirst = /^https?:\/\/[^\s\]]/.test(target);
    const match = (isHrefFirst ? /^https?:\/\/[^\s\]]+/ : /https?:\/\/[^\s\]]+$/).exec(target);
    if (match === null) {
        return [];
    }
    const c = isHrefFirst ? target.substring(match[0].length) : target.substring(0, match.index - 1);
    return {
        type: 'link',
        pathType: 'absolute',
        href: match[0],
        content: c.trim()
    };
};
exports.ExternalLinkNodeParser = creator_1.createNodeParser(createExternalLinkNode, {
    parseOnNested: true,
    parseOnQuoted: true,
    patterns: [hrefFirstUrlRegExp, contentFirstUrlRegExp, httpRegExp]
});
//# sourceMappingURL=ExternalLinkNode.js.map